@@ -301,9 +301,27 @@ impl<'daft, T: ?Sized + TriHashItem, S: Default, A: Allocator + Default> Default
     }
 }
 
+impl<'a, 'daft, T, S, A: Allocator> fmt::Debug for Diff<'daft, T, S, A>
+where
+    T: ?Sized + TriHashItem + fmt::Debug,
+    T::K1<'a>: fmt::Debug,
+    T::K2<'a>: fmt::Debug,
+    T::K3<'a>: fmt::Debug,
+    T: 'a,
+    'daft: 'a,
+{
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        f.debug_struct("Diff")
+            .field("common", &self.common)
+            .field("added", &self.added)
+            .field("removed", &self.removed)
+            .finish()
+    }
+}
+
 #[cfg(all(feature = "default-hasher", feature = "allocator-api2"))]
 impl<'daft, T: ?Sized + TriHashItem> Diff<'daft, T> {
-    /// Creates a new `TriHashMapDiff` from two maps.
+    /// Creates a new, empty `Diff`.
     pub fn new() -> Self {
         Self {
             common: TriHashMap::new(),
@@ -315,7 +333,7 @@ impl<'daft, T: ?Sized + TriHashItem> Diff<'daft, T> {
 
 #[cfg(feature = "allocator-api2")]
 impl<'daft, T: ?Sized + TriHashItem, S: Clone + BuildHasher> Diff<'daft, T, S> {
-    /// Creates a new `TriHashMapDiff` with the given hasher.
+    /// Creates a new, empty `Diff` with the given hasher.
     pub fn with_hasher(hasher: S) -> Self {
         Self {
             common: TriHashMap::with_hasher(hasher.clone()),
@@ -332,7 +350,7 @@ impl<
     A: Clone + Allocator,
 > Diff<'daft, T, S, A>
 {
-    /// Creates a new `TriHashMapDiff` with the given hasher and allocator.
+    /// Creates a new, empty `Diff` with the given hasher and allocator.
     pub fn with_hasher_in(hasher: S, alloc: A) -> Self {
         Self {
             common: TriHashMap::with_hasher_in(hasher.clone(), alloc.clone()),
@@ -505,7 +523,7 @@ impl<T: TriHashItem> TriHashItem for IdLeaf<T> {
         if before_key != self.after().key1() {
             panic!("key1 is different between before and after");
         }
-        self.before().key1()
+        before_key
     }
 
     fn key2(&self) -> Self::K2<'_> {
@@ -513,7 +531,7 @@ impl<T: TriHashItem> TriHashItem for IdLeaf<T> {
         if before_key != self.after().key2() {
             panic!("key2 is different between before and after");
         }
-        self.before().key2()
+        before_key
     }
 
     fn key3(&self) -> Self::K3<'_> {
@@ -521,7 +539,7 @@ impl<T: TriHashItem> TriHashItem for IdLeaf<T> {
         if before_key != self.after().key3() {
             panic!("key3 is different between before and after");
         }
-        self.before().key3()
+        before_key
     }
 
     #[inline]
