@@ -6,6 +6,8 @@
 mod daft_impls;
 pub(crate) mod imp;
 mod iter;
+#[cfg(feature = "proptest")]
+mod proptest_impls;
 mod ref_mut;
 #[cfg(feature = "schemars08")]
 mod schemars_impls;
@@ -18,5 +20,12 @@ pub(crate) mod trait_defs;
 pub use daft_impls::{ByK1, ByK2, ByK3, Diff, MapLeaf};
 pub use imp::TriHashMap;
 pub use iter::{IntoIter, Iter, IterMut};
+#[cfg(all(feature = "proptest", feature = "default-hasher"))]
+pub use proptest_impls::prop_strategy;
+#[cfg(feature = "proptest")]
+pub use proptest_impls::{
+    TriHashMapStrategy, TriHashMapValueTree, prop_strategy_with_hasher,
+    prop_strategy_with_hasher_in,
+};
 pub use ref_mut::RefMut;
 pub use trait_defs::TriHashItem;
